﻿<%@ WebHandler Language="C#" Class="Customers" %>
using System;
using System.Web;
using System.IO;
using Newtonsoft.Json.Linq;
using Newtonsoft.Json;
using System.Data;


public class Customers : IHttpHandler
{

    public void ProcessRequest(HttpContext context)
    {
        context.Response.AddHeader("Access-Control-Allow-Origin", "*");
        context.Response.AddHeader("Access-Control-Allow-Methods", "GET, POST");
        context.Response.AddHeader("Access-Control-Allow-Headers", "Content-Type, Accept");
        context.Response.ContentType = "application/json";
        WebResponse response = new WebResponse();
        try
        {
            if (!WebUser.CanXML())
            {
                context.Response.StatusCode = (int)System.Net.HttpStatusCode.BadRequest;
                response.error = "Web2Print is not enabled for this account";
                context.Response.Write("Web2Plan Not Enabled");
                return;
            }

            if (context.Request.RequestType == "GET" || context.Request.RequestType == "POST")
            {
                string action = context.Request.QueryString["action"] == null ? "" : context.Request.QueryString["action"].ToLower();
                CustomerApi cusApi = new CustomerApi();


                DataTable Web2PrintTb = DataBase.GetDataTable("SELECT * FROM Web2Print");
                DataRow W2Prow = Web2PrintTb.Rows[0];
                string SecretKey = W2Prow["SecretKey"].ToString();
                string key = context.Request.QueryString["key"] == null ? "" : context.Request.QueryString["key"].ToString();

                if (SecretKey == "")
                {
                    response.error = "Secret key needs to be set inside of Printers Plan";
                    context.Response.StatusCode = (int)System.Net.HttpStatusCode.InternalServerError;
                    context.Response.Write(JsonConvert.SerializeObject(response));
                    return;
                }

                if (key != SecretKey)
                {
                    response.error = "Secret key does not match";
                    context.Response.StatusCode = (int)System.Net.HttpStatusCode.BadRequest;
                    context.Response.Write(JsonConvert.SerializeObject(response));
                    return;
                }

                if (context.Request.RequestType == "GET")
                {
                    switch (action)
                    {
                        case "customerlist":
                            response = cusApi.GetCustomerList();
                            break;
                        case "contactlist":
                            response = cusApi.GetContactList(context.Request.QueryString["customerno"] == null ? "" : context.Request.QueryString["customerno"].ToLower(), (context.Request.QueryString["email"] == null ? "" : context.Request.QueryString["email"].ToLower()));
                            break;
                        case "contacttokenlist":
                            response = cusApi.GetContactTokenList(Int32.Parse(context.Request.QueryString["contactno"] == null ? "" : context.Request.QueryString["contactno"].ToLower()));
                            break;
                        case "customertokenlist":
                            response = cusApi.GetCustomerTokenList(Int32.Parse(context.Request.QueryString["customerno"] == null ? "" : context.Request.QueryString["customerno"].ToLower()));
                            break;
                        case "customer":
                            response = cusApi.GetCustomer(Int32.Parse(context.Request.QueryString["customerno"] == null ? "" : context.Request.QueryString["customerno"].ToLower()));
                            break;
                        default:
                            response.isSuccessful = false;
                            response.error = "Method name does not exist";
                            context.Response.StatusCode = (int)System.Net.HttpStatusCode.BadRequest;
                            context.Response.Write(JsonConvert.SerializeObject(response));
                            return;
                    }
                }
                else
                {
                    var requestBody = string.Empty;
                    using (StreamReader reader = new StreamReader(context.Request.InputStream))
                    {
                        context.Request.InputStream.Position = 0;                                   //We need to set the Stream position to 0 before ReadToEnd otherwise we get a null requestBody
                        requestBody = context.Server.UrlDecode(reader.ReadToEnd());
                    }

                    JObject Json = new JObject();
                    try
                    {
                        Json = JObject.Parse(requestBody);
                    }
                    catch (Exception ex)
                    {
                        context.Response.StatusCode = (int)System.Net.HttpStatusCode.InternalServerError;
                        response.error = ex.Message;
                        context.Response.Write(JsonConvert.SerializeObject(response));
                        return;
                    }

                    switch (action)
                    {
                        case "contacttokenadd":
                            ContactAddTokenModel.Root requestAdd = new ContactAddTokenModel.Root();
                            requestAdd = Json.ToObject<ContactAddTokenModel.Root>();

                            response = cusApi.AddContactToken(requestAdd);
                            break;
                        case "contacttokenremove":
                            response = cusApi.RemoveContactToken(Json["requestDetails"]["token"].ToString());
                            break;
                        case "contacttokensetdefault":
                            response = cusApi.SetContactDefaultToken(Json);
                            break;
                        case "contacttokenupdate":
                            ContactUpdateTokenModel.Root requestUpdate = new ContactUpdateTokenModel.Root();
                            requestUpdate = Json.ToObject<ContactUpdateTokenModel.Root>();

                            response = cusApi.UpdateContactToken(requestUpdate);
                            break;
                        default:
                            response.isSuccessful = false;
                            response.error = "Method name does not exist";
                            context.Response.StatusCode = (int)System.Net.HttpStatusCode.BadRequest;
                            context.Response.Write(JsonConvert.SerializeObject(response));
                            return;
                    }

                }

                if (response.isSuccessful) //Log a success if a no error
                {
                    //Files.WriteErrorLog(DateTime.Now.ToString("MM/dd/yyyy h:mm tt ") + InvoiceID + " invoice paid - Amount: " + AmountPaid, "_PrintReachPayWebhookLog");
                    context.Response.StatusCode = (int)System.Net.HttpStatusCode.OK;
                    context.Response.Write(JsonConvert.SerializeObject(response));
                    return;
                }
                else
                {
                    context.Response.StatusCode = (int)System.Net.HttpStatusCode.InternalServerError;
                    context.Response.Write(JsonConvert.SerializeObject(response));
                    return;
                    //Files.WriteErrorLog(DateTime.Now.ToString("MM/dd/yyyy h:mm tt") + " - PrintReach Pay Payment Failure: Internal Server error/n Json: " + decodedbody, "_PrintReachPayWebhookLog");
                }

            }
            else
            {
                context.Response.StatusCode = (int)System.Net.HttpStatusCode.MethodNotAllowed;
                response.error = "This listener does not support this request type";
                context.Response.Write(JsonConvert.SerializeObject(response));
                return;
            }
        }
        catch (Exception e)
        {

            context.Response.StatusCode = (int)System.Net.HttpStatusCode.BadRequest;
            response.error = e.Message;
            context.Response.Write(JsonConvert.SerializeObject(response));
        }
    }

    public bool IsReusable
    {
        get
        {
            return false;
        }
    }

}